/*
 * Copyright 2021 Associated Universities, Inc.
 *
 * This file is part of Telescope Time Allocation Tools (TTAT).
 *
 * TTAT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * TTAT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TTAT.  If not, see <https://www.gnu.org/licenses/>.
 *
 */
import {Component, OnInit} from '@angular/core';
import {Subscription} from 'rxjs';
import {faTimes} from '@fortawesome/free-solid-svg-icons';
import {AlertMessage, AlertService} from "../services/alert/alert.service";

@Component({
  selector: 'app-alert',
  templateUrl: './alert.component.html',
  styleUrls: ['./alert.component.scss']
})
export class AlertComponent implements OnInit {

  private subscription: Subscription | undefined;
  public message: AlertMessage | null | undefined;

  public faTimes = faTimes;

  constructor(private alertService: AlertService) {
  }

  ngOnInit() {
    this.subscription = this.alertService.getMessage().subscribe((message: AlertMessage) => {
      this.message = message;
      setTimeout(() => {
        this.clearMessage();
      }, 5000);
    })
  }

  clearMessage(): void {
    this.message = null;
  }

  ngOnDestroy(): void {
    if (this.subscription) {
      this.subscription.unsubscribe();
    }
  }

}
