/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Injectable } from '@angular/core';
import {BehaviorSubject, Observable} from "rxjs";
import {User} from "../model/user";
import {StorageService} from "./storage/storage.service";

@Injectable({
  providedIn: 'root'
})
export class UserService {

  private users: Array<User> = [];
  private _users: BehaviorSubject<Array<User>> = new BehaviorSubject<Array<User>>(this.users);

  public readonly users$: Observable<Array<User>> = this._users.asObservable();
  private readonly endPoint = `users`;

  constructor(private storage: StorageService) {
    this.loadUsers();
  }

  /**
   * loadUsers
   */
  loadUsers(): void {
    const loadedUsers = this.storage.getLocal(this.endPoint);
    if (loadedUsers) {
      this.users = JSON.parse(loadedUsers) as Array<User>;
      this._users.next(this.users);
    }
  }

  /**
   * get a User
   */
  getUser(id: number): User | undefined {
    for (const user of this.users) {
      if (user.id === id) {
        return user;
      }
    }
    return undefined;
  }

  /**
   * create a User
   */
  upsertUser(user: User): void {
    for (let i = 0; i < this.users.length; i++) {
      if (this.users[i].id === user.id) {
        this.users.splice(i, 1, user);
        return;
      }
    }
    // if we didn't return already, this User wasn't in the list, so add it
    this.users.push(user);
    this._users.next(this.users);
  }

  /**
   * delete a User
   */
  deleteUser(user: User): void {
    for (let i = 0; i < this.users.length; i++) {
      if (this.users[i].id === user.id) {
        this.users.splice(i, 1);
        this._users.next(this.users);
      }
    }
    throw new Error('Delete failed, that Users was not found');
  }
}
